#! /bin/csh -f
#
#	REFMAC benchmark script
#
###############################################################################
set pdbin = model4.pdb

set refmac = refmac
if( $1 != "") set refmac = "$1"

protin:
###############################################################################
#
#   Run protin  to set up geometric restraints
#
protin \
XYZIN      $pdbin \
PROTOUT    protout.dat		\
PROTCOUNTS counts.dat		\
<< eof
# automatically determined chains
CHNNAM ID A CHNTYP 1
CHNNAM ID B CHNTYP 2
CHNNAM ID C CHNTYP 3
CHNNAM ID X CHNTYP 4
CHNNAM ID S CHNTYP 5
#capping groups: 5=acetyl, 4=formyl, 3=amino, 2=carboxyl
CHNTYP 1 NTERM 1 ARG 5 CTERM 33 ARG 2
#CHNTYP 1 CISPEP 1    25      # cis-peptide bonds
#CHNTYP 1 SECO    4   23 1    # helix
#CHNTYP 1 SECO    4   23 9    # B-bend I 
CHNTYP 2 NTERM 1 ARG 5 CTERM 33 ARG 2
#CHNTYP 2 SECO    3   27 1    # helix
#CHNTYP 2 SECO    3   28 9    # B-bend I 
CHNTYP 3 NTERM 1 ARG 5 CTERM 32 GLU 2
#CHNTYP 3 CISPEP 2    6 22      # cis-peptide bonds
#CHNTYP 3 SECO    8   19 9    # B-bend I 
#CHNTYP 3 SECO    9   19 1    # helix
#CHNTYP 3 SECO   12   14 3    # pi helix
#CHNTYP 3 SECO   22   28 9    # B-bend I 
#CHNTYP 3 SECO   25   27 1    # helix
CHNTYP 4 WAT
CHNTYP 5 WAT

# NCS chains A,B,and C from residues 2-33, 40-77 code 2
# code 1 2 3 4 5 6 
# main t t t m m l
# side t m l m l l
#NONX 3 CHNID A B C NSPANS 2    2 33    2    40 77     2

# of atoms in peptide bond 5 -> Ca to Ca (default)
PEPP 5
SYMM P3121
#VDWRadii 1 CA 7 3.8
# VDW cuttoff distance (5 default)
VDWCUT 5
END
eof
if($status) then
    exit 2
endif
###############################################################################
#
# Refmac step. Refine
#
$refmac \
HKLIN      data.mtz \
HKLOUT     ./refmacout.mtz \
XYZIN      $pdbin \
XYZOUT     ./refmacout.pdb \
PROTOUT    protout.dat \
PROTCOUNTS counts.dat \
PROTSCR    counts.scr \
<< END-OF-REFMAC 
LABIN FP=F SIGFP=SIGF  FREE=FreeR_flag  
LABO FC=FC PHIC=PHIC    FWT=2FOFCWT PHWT=PH2FOFCWT -
                     DELFWT=FOFCWT  PHDELWT=PHFOFCWT
# RESTRAINED, RIGID, or IDEAL (geometry only)
REFI TYPE RESTrained 
# default: refine agains full resolution range
#REFI RESOLUTION  79.057 1.790
# use maximum-likelihood, conjugate-direction refinement (with phases)
REFI RESIDUAL MLKF METHOD CDIR PHASED
# One, overall B (OVERALL) or individual Bs (ISOTROPIC)
REFI BREF ISOTROPIC

#weight of X-ray over geometry (default: WEIG EXPE MATR 0.5)
WEIG EXPE MATR 0.5
# No torsional restraints (combine with low WEIG ? )
#TORSION 0.0
# Bfactor restraints weight
#BFAC 1.0
# NCS restraints weight
#NCSR 1.0

#Blur the phases?
#PHASE SCBL 1 BBLUR 0
# combine experimental phases with calculated ones in output maps
REFI PHASE SIGMAcalc

# Fo-Fc SCALING 
#Scale Fc to Fo with 2-Gaussian fit (TYPE SIMPLE is 1-Gaussian)
SCALE TYPE BULK 
# use an anisotropic, overall B factor (for anisotropic diffraction)
SCALE LSSC ANIS 
# low-res cutoff for scaling (intended for SCALE TYPE SIMPLE)
#SCALE RESO 4.5 1.790

# fix water/protein density ratio to 1/1.35 and water B=80 in scaling
#SCALE LSSC FIXBULK SCBULK -0.74 BBULK 80
# same for SigmaA estimation (NOT recommended)
#SCALE MLSC FIXBULK SCBULK -0.5  BBULK 100

# use free-R hkls in scaling (ignored by default)
#SCALE LSSC FREE
# use experimental sigmas in scaling (ignored by default)
#SCALE LSSC EXPE


# Actual number of REFMAC refinement steps per cycle (5 default)
NCYC 10


# verboseness
MONI FEW
#MONI MEDI HBOND
#MONI MEDI CHIRAL 0.5
#MONI MANY
# 20 display bins by default
#BINS 20
end
END-OF-REFMAC
#
# update the output file
#
# Clean up
#
exit


