#! /bin/csh -f
#
#	refmac benchmark testing script
#
#
#
# set these to a FAST directory (local)
setenv CCP4_SCR .
setenv BINSORT_SCR .
set tempfile = tempfile$$

set itrs = 3


# probe machine for info
set uname = `uname -a`




# allow user override of parameters
foreach arg ( $* )
    if("$arg" =~ *=*) then
        set values = `echo $arg | awk -F "=" '{print $2}' | awk 'BEGIN{RS=","} {print}'`
        if("$arg" =~ itr*) then
            set itrs = `echo $arg | awk -F "=" '{print $2+0}'`
        endif
    endif
    if("$arg" =~ *setup*) then
        echo "sourcing $arg"
        source $arg
    endif
    if("$arg" == "send") then
        unset NOSEND
        goto send
    endif
    if("$arg" == "nosend") then
        set NOSEND
    endif
end


# jiffy for finding refmac executable

foreach candidate ( $* `which refmac5` ./refmac5 refmac5 )
    if( "$candidate" !~ *refmac* ) continue
    set refmac = $candidate
    if(-e $refmac) break
end

if((! $?CLIBD)||(! $?CLIBD_MON)||(! $?CINCL) && -e ./data/monomers/ ) then

    # do minimal setup
    setenv CINCL    .
    setenv CLIBD    ./data/
    setenv CLIBD_MON ./data/monomers/

    setenv LD_LIBRARY_PATH ./lib/
endif



# figure out how to measure time

if (! -x ./log_timestamp.tcl) then
    cat << EOF >! log_timestamp.tcl
#! /bin/sh
# use tclsh in the path \
exec tclsh "\$0" "\$@"
#
#       encode a logfile stream with time stamps
#
#
#
set start [expr [clock clicks -milliseconds]/1000.0]

while { ! [eof stdin] } {
    set line "[gets stdin]"
    puts "[clock format [clock seconds] -format "%a %b %d %T %Z %Y"] [clock seconds] [format "%12.3f" [expr [clock clicks -milliseconds]/1000.0 - \$start]] \$line"

}
EOF
    chmod a+x log_timestamp.tcl
endif


set test = `echo | ./log_timestamp.tcl | awk '{print ( $7+0>1000000 )}' | tail -n 1`
if("$test" == "1") then
    set timestamper = ./log_timestamp.tcl
else
    echo "WARNING: tcl does not work, resorting to low-precision timer"
    # hmm.  Maybe tcl not installed
    cat << EOF >! timer.csh
#! /bin/csh -f
#
set starttime = \`date +%s\`

cat

set endtime = \`date +%s\`
@ deltaT = ( \$endtime - \$starttime )
echo "\`date\` \$endtime \$deltaT"
EOF
    chmod a+x timer.csh
    set timestamper = ./timer.csh
endif




foreach itr ( `seq 1 $itrs` )

echo "refining for 10 cycles with $refmac"
rm -f refmacout.mtz
./refmac.com $refmac | $timestamper >! refmac${itr}.log &


sleep 5
# now that CPUs are hot, collect machine data
uname -a >! machineinfo.txt
set uname = `awk '{print $1;exit}' machineinfo.txt`
uptime >> machineinfo.txt

if("$uname" == "Linux" || "$uname" =~ CYGWIN*) then
    free -m >> machineinfo.txt
    cat /proc/cpuinfo >> machineinfo.txt
endif
if("$uname" == "Darwin") then
    sysctl hw >> machineinfo.txt
endif
set test = `cat machineinfo.txt | wc -l | awk '{print ($1<10)}'`
if($test) then
    echo "WARNING: unknown platform! "
endif
grep MHz machineinfo.txt | sort -k4gr | head -n 1

wait

set test = `ls -l refmacout.mtz | awk '{print ($5>1000000)}'`
if("$test" != "1") then
    echo "trying old refmac "
    mv refmac${itr}.log bad_refmac${itr}.log
    ./refmac4.com | $timestamper >! refmac${itr}.log &
endif
wait

set test = `ls -l refmacout.mtz | awk '{print ($5>1000000)}'`
if("$test" != "1") then
    set BAD = "$refmac failed to run"
    goto exit
endif

awk '/Times: User:/{print}' refmac${itr}.log |\
 tail -n 1 |\
 tee -a timings.txt

end

set test = `cat timings.txt | wc -l` 
if("$test" == "0") then
    set BAD = "no results."
    goto exit
endif



send:
# make this cumulative
touch results.txt
sort -u timings.txt | awk '{print "runtime: ",$0}' >> results.txt
hostname >> results.txt
grep version refmac1.log >> results.txt
awk '! seen[$0]{print;++seen[$0]}' machineinfo.txt >> results.txt


if($?NOSEND) then
    echo "please send in your results by running: $0 send"
    goto exit
endif
echo "sending results..."
set sanskrit = `gzip -c results.txt | base64 | awk '{gsub("/","_");gsub("[+]","-");printf("%s",$0)}'`
if("$sanskrit" != "") then
    curl http://bl831.als.lbl.gov/refmac_bench$sanskrit > /dev/null
endif
if($status || "$sanskrit" == "") then
    echo "ERROR: please send file results.txt manually to JMHolton@lbl.gov"
endif


exit:

if($?BAD) then
    echo "ERROR: $BAD"
    exit 9
endif

exit





exit




# on most machines:

mkdir -p ~/projects/benchmarks/refmac/
#curl http://bl831.als.lbl.gov/~jamesh/benchmarks/refmac_bmark.tgz >! ~/projects/benchmarks/refmac/refmac_bmark.tgz
mkdir -p /dev/shm/refmac_bench/
cd /dev/shm/refmac_bench
tar xzvf ~/projects/benchmarks/refmac/refmac_bmark.tgz
cd refmac_bmark/
./test.com nosend
cp results.txt ~/projects/benchmarks/refmac/results_`hostname -s`.txt

cd ../
tar xzvf ~/projects/benchmarks/refmac/refmac_bmark.tgz
cd refmac_bmark/
rm -f results.txt
./test.com nosend
cp results.txt ~/projects/benchmarks/refmac/results_`hostname -s`.txt







# figuring out what we need to pack for lunch
./refmac.com | & tee strace.log | grep -i ccp4


 grep ccp4 strace.log | awk -F '"' '/^open/{print $2}' | awk '/.so$/{print "cp",$1,"lib"}'

 grep ccp4 strace.log | awk -F '"' '/^open/{print $2}' | awk '/data/{file=substr($1,index($1,"data"));dir=file;while(gsub("[^/]$","",dir));print "mkdir -p",dir,"; cp",$1,file}'


cd ..
awk '{print "refmac_bmark/"$1}' << EOF | tar czvTf - ~/html/benchmarks/refmac_bmark.tgz
test.com
refmac.com
data.mtz
model.pdb
refmac4.com
model4.pdb
environ.def
default.def
refmac5
data
lib
EOF
cd - 

curl http://smb.slac.stanford.edu/~holton/benchmarks/refmac_bmark.tgz | tar xvzf -












set sourcemes = `ls -1rt /programs/ccp4-*/bin/refmac5 /programs/ccp4*/*/bin/refmac5 | awk '{gsub("bin/refmac5","include/ccp4.setup");print}'`

foreach source ( $sourcemes )

   rm -f timings.txt
   ./test.com $source

end





